//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[ChildPoint](index.md)/[ChildPoint](-child-point.md)

# ChildPoint

[common]\
constructor(ron: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), tsumoParent: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), tsumoChild: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html))
